@@ -19,7 +19,9 @@ require 'spec_helper'
 describe 'tripleo::profile::base::gnocchi::api' do
   shared_examples_for 'tripleo::profile::base::gnocchi::api' do
     let(:pre_condition) do
-      "class { '::tripleo::profile::base::gnocchi': step => #{params[:step]}, }"
+      "
+        class { '::tripleo::profile::base::gnocchi': step => #{params[:step]}, }
+      "
     end
 
     context 'with step less than 3' do
@@ -36,9 +38,9 @@ describe 'tripleo::profile::base::gnocchi::api' do
       }
     end
 
-    context 'with step 3 on bootstrap' do
+    context 'with step 4 on bootstrap' do
       let(:params) { {
-        :step => 3,
+        :step => 4,
         :bootstrap_node => 'node.example.com',
         :gnocchi_redis_password => 'gnocchi',
         :redis_vip => '127.0.0.1'
@@ -51,20 +53,6 @@ describe 'tripleo::profile::base::gnocchi::api' do
       }
     end
 
-    context 'with step 3' do
-      let(:params) { {
-        :step => 3,
-        :gnocchi_redis_password => 'gnocchi',
-        :redis_vip => '127.0.0.1'
-      } }
-
-      it {
-        is_expected.to_not contain_class('gnocchi::db::sync')
-        is_expected.to contain_class('gnocchi::api')
-        is_expected.to contain_class('gnocchi::wsgi::apache')
-      }
-    end
-
     context 'with step 4' do
       let(:params) { {
         :step => 4,
@@ -96,6 +84,9 @@ describe 'tripleo::profile::base::gnocchi::api' do
         is_expected.to contain_class('gnocchi::storage').with(
           :coordination_url => 'redis://:gnocchi@127.0.0.1:6379/'
         )
+        is_expected.to contain_class('gnocchi::storage::incoming::redis').with(
+          :redis_url => 'redis://:gnocchi@127.0.0.1:6379/'
+        )
         is_expected.to contain_class('gnocchi::storage::file')
       }
     end
@@ -105,7 +96,8 @@ describe 'tripleo::profile::base::gnocchi::api' do
         :step => 4,
         :gnocchi_backend => 'rbd',
         :gnocchi_redis_password => 'gnocchi',
-        :redis_vip => '127.0.0.1'
+        :redis_vip => '127.0.0.1',
+        :gnocchi_rbd_client_name => 'openstack'
       } }
 
       it {
@@ -114,7 +106,11 @@ describe 'tripleo::profile::base::gnocchi::api' do
         is_expected.to contain_class('gnocchi::storage').with(
           :coordination_url => 'redis://:gnocchi@127.0.0.1:6379/'
         )
+        is_expected.to contain_class('gnocchi::storage::incoming::redis').with(
+          :redis_url => 'redis://:gnocchi@127.0.0.1:6379/'
+        )
         is_expected.to contain_class('gnocchi::storage::ceph')
+        is_expected.to contain_exec('exec-setfacl-openstack-gnocchi')
       }
     end
 
@@ -129,10 +125,6 @@ describe 'tripleo::profile::base::gnocchi::api' do
       it {
         is_expected.to contain_class('gnocchi::api')
         is_expected.to contain_class('gnocchi::wsgi::apache')
-        is_expected.to contain_exec('run gnocchi upgrade with storage').with(
-          :command => 'gnocchi-upgrade --config-file=/etc/gnocchi/gnocchi.conf',
-          :path    => ['/usr/bin', '/usr/sbin']
-        )
       }
     end
   end
